@@ -1,11 +1,12 @@
-#'@title Predicted probabilities of regimes of a univariate HMM given a new observation
+#'@title Predicted probabilities of regimes of a univariate HMM for a new observation
 #'
 #'@description This function computes the predicted probabilities of the regimes for a new observation of a univariate HMM, given observations up to time n
 #'
-#'@param ynew  the new observations
-#'@param family    distribution name; run the function distributions() for help
+#'@param ynew   new observations
+#'@param ZI     1 if zero-inflated, 0 otherwise (default)
+#'@param family distribution name; run the function distributions() for help
 #'@param theta  parameters; (r  x p)
-#'@param Q    probability transition  matrix; (r  x r)
+#'@param Q      probability transition  matrix for the regimes; (r  x r)
 #'@param eta    vector of the estimated probability of each regime at time n; (1  x r)
 #'
 #'
@@ -13,19 +14,15 @@
 #'
 #'@examples
 #'family = "gaussian"
-#'
 #'theta = matrix(c(-1.5, 1.7, 1, 1),2,2)
 #'Q = matrix(c(0.8, 0.3, 0.2, 0.7), 2, 2)
-#'eta = c(0.96091218, 0.03908782)
-#'
-#'forecastedhmmeta = ForecastHMMeta(c(1.5), family, theta=theta, Q=Q, eta=eta)
-#'print('Forecasted regime probabilities : ')
-#'print(forecastedhmmeta)
+#'eta = c(0.96, 0.04)
+#'ForecastHMMeta(1.5, 0, family, theta, Q, eta)
 #'
 #'@export
 
 
-ForecastHMMeta<-function(ynew, family, theta, Q, eta){
+ForecastHMMeta<-function(ynew, ZI=0, family, theta, Q, eta){
 
   if(is.null(dim(Q))){
     QQ0 = matrix(Q)
@@ -34,15 +31,25 @@ ForecastHMMeta<-function(ynew, family, theta, Q, eta){
     r = dim(Q)[2]
   }
 
+  un = 1+ZI
+
   etanew = matrix(0, nrow=length(ynew), ncol=r)
 
-  for (j in 1:r){
+  for (j in un:r){
     for (l in 1:r){
       etanew[,j] = etanew[,j] + eta[l] * Q[l, j]
     }
     etanew[,j] = etanew[,j] * PDF(family, ynew, theta[j,])
   }
 
+  if(ZI==1)
+  {
+    for (l in 1:r){
+      etanew[,1] = etanew[,1] + eta[l] * Q[l, 1]
+    }
+    etanew[,1] = etanew[,1] * (ynew==0)
+  }
+
   etanew = etanew / rowSums(etanew)
 
   return(etanew)
